SystemOrganization addCategory: #'Seaside-Environment'!

WAObject subclass: #WAAdmin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAAdmin class methodsFor: 'private' stamp: 'lr 10/21/2008 15:40'!
applicationDefaults
	| config |
	config := WASharedConfiguration named: 'Application Defaults'.
	config parents isEmpty ifFalse: [ ^ config ].
	config
		addParent: WAApplicationConfiguration instance;
		addParent: WARenderLoopConfiguration instance;
		at: #exceptionHandler put: WAHtmlErrorHandler;
		at: #libraries addAll: (Array with: WAStandardFiles);
		at: #responseFactory put: WAHtmlResponseFactory.
	^ config! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/17/2008 20:58'!
clearConfigurationCaches
	WASystemConfiguration clearAllDescriptions! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 10/27/2008 11:27'!
clearSessions
	WARegistry clearAll! !

!WAAdmin class methodsFor: 'private' stamp: 'jf 10/26/2008 12:19'!
defaultDispatcher
	^ WADispatcher default! !

!WAAdmin class methodsFor: 'initialization' stamp: 'lr 10/21/2008 15:35'!
initialize
	self reloadApplications! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:26'!
register: aComponentClass asApplicationAt: aString
	"Use this to programatically register a component as an application."
	"WARenderLoopConfiguration is added by default because most users will use WASession and the Render Loop."
	| application |
	application := self register: WAApplication at: aString.
	application configuration
		removeParent: WASessionConfiguration instance; "make the chain slightly cleaner"
		addParent: WARenderLoopConfiguration instance;
		addParent: self applicationDefaults.
	application preferenceAt: #rootClass put: aComponentClass.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:17'!
register: aComponentClass asApplicationAt: aString user: user password: password
	"Like #register:asApplicationAt: but additionally adds password protection."
	| application |
	application := self register: aComponentClass asApplicationAt: aString.
	application configuration addParent: WAAuthConfiguration instance.
	application 
		preferenceAt: #login
		put: user.
	application 
		preferenceAt: #passwordHash
		put: (SeasidePlatformSupport secureHashFor: password).
	application
		addFilter: WAAuthenticationFilter new.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:19'!
register: anEntryPointClass at: aString
	^ self register: anEntryPointClass at: aString in: self defaultDispatcher! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:15'!
register: anEntryPointClass at: aString in: aDispatcher
	| path dispatcher |
	path := aString findTokens: '/'.
	dispatcher := path allButLast
		inject: aDispatcher
		into: [ :result :each |
			result entryPoints 
				at: each
				ifAbsent: [ result register: (WADispatcher named: each) ] ].
	^ dispatcher register: (anEntryPointClass named: path last)! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 18:10'!
registerDefaultComponents
	WAPresenter allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 11/9/2008 18:00'!
registerDefaultRequestHandlers
	WAFileHandler default: (WAFileHandler named: 'files').
	WAFileHandler default preferenceAt: #fileHandlerListingClass put: WAHtmlFileHandlerListing.
	WADispatcher default register: WAFileHandler default! !

!WAAdmin class methodsFor: 'development' stamp: 'lr 10/21/2008 15:30'!
reloadApplications
	WADispatcher resetDefault.
	WASystemConfiguration clearAllDescriptions.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

!WADispatcher class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
resetAll
	self
		seasideDeprecatedApi: 'WADispatcher class>>#resetAll'
		details: 'Use WAAdmin>>#reloadApplications.'.
	WAAdmin reloadApplications! !

!WAEntryPoint class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
register: aString
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:'
		details: 'Use WAAdmin class>>#register:at:.'.
	^ WAAdmin register: self at: aString! !

!WAEntryPoint class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
register: aString in: aDispatcher
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:in:'
		details: 'Use WAAdmin class>>#register:at:in:.'.
	^ WAAdmin register: self at: aString in: aDispatcher! !

WAErrorHandler subclass: #WAHtmlErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlErrorHandler commentStamp: 'jf 11/10/2008 10:07' prior: 0!
This exception handler returns a simple HTML error message response for Warnings and Errors.

It provides two methods to allow the easy creation of custom error responses:

#titleForException:  - can be used to override the text displayed in the title
#renderContentForException:  - can be used to fully customize the HTML output!

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 12/29/2008 19:27'!
handleDefault: anException
	| response content |
	response := WAResponse new.
	response internalError.
	content := self rendererClass builder
		fullDocument: true;
		rootBlock: [ :root | root title: (self titleForException: anException) ];
		render: [ :html | self renderContentForException: anException on: html ].
	response nextPutAll: content.
	^ response! !

!WAHtmlErrorHandler methodsFor: 'actions' stamp: 'jf 11/10/2008 10:04'!
renderContentForException: anException on: html
	html heading level1; with: anException description.
	html paragraph: 'Your request could not be completed. An exception occurred.'! !

!WAHtmlErrorHandler methodsFor: 'accessing' stamp: 'jf 12/29/2008 19:27'!
rendererClass
	^ WARenderCanvas! !

!WAHtmlErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 20:28'!
titleForException: anException
	^ anException description! !

!WAPackage class methodsFor: '*seaside-environment' stamp: 'lr 11/30/2008 13:40'!
seasideEnvironment
	^ self new
		name: 'Seaside-Environment';
		description: 'Administrative tools, useful to have for productive and development environments.';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component';
		addDependency: 'Seaside-RenderLoop';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Canvas';
		yourself! !

WAFileHandlerListing subclass: #WAHtmlFileHandlerListing
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 11/9/2008 17:32'!
responseForLibraries
	| title |
	title := 'Index of ', handler basePath.
	^ WARenderCanvas builder
		rootBlock: [ :html | html title: title ];
		renderResponse: [ :html |
			html heading: title.
			html unorderedList: [
				handler libraries do: [ :each |
					html listItem: [
						html anchor
							url: (each urlOf: '');
							with: each name ] ] ] ]! !

!WAHtmlFileHandlerListing methodsFor: 'responding' stamp: 'jf 11/9/2008 17:32'!
responseForLibrary: aLibrary
	| title |
	title := 'Index of ', aLibrary name.
	^ WARenderCanvas builder
		rootBlock: [ :html | html title: title ];
		renderResponse: [ :html |
			html heading level: 1; with: title.
			html table: [
				html tableRow: [
					html tableHeading: 'Name'.
					html tableHeading: 'Size'.
					html tableHeading: 'Description' ].
				aLibrary fileSelectors do: [ :each |
					html tableRow: [
						html tableData: [
							html anchor
								url: (aLibrary urlOf: each);
								with: (aLibrary asFilename: each) ].
						html tableData: (aLibrary perform: each) size.
						html tableData: (aLibrary mimetypeForFile: (aLibrary asFilename: each)) ] ] ] ]! !

WAFileLibrary subclass: #WAStandardFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAStandardFiles commentStamp: 'jf 10/6/2008 21:39' prior: 0!
A collection of standard scripts, styles, and images.

#windowCss styles the HTML created by WAWindowDecoration.
#shortcutJs creates the JavaScript used by WATagBrush>>addShortcut:.
#miscJs creates JavaScript used by:
	- WACheckboxTag>>submitFormNamed:
	- WAFormInputTag>>setFocus
	- WAAbstractTextAreaTag>>setSelectionFrom:to:
	- (the rest of the JS functions appear to be uncalled in the Seaside codebase)
#kalseyTabCss styles the HTML created by WANavigation
#externalAnchorJs sets a target of _blank for any anchor that has a "rel" attribute
	of "external". However, the JS function does not appear to be called anywhere
	in Seaside.!

!WAStandardFiles methodsFor: 'accessing-styles' stamp: 'lr 10/28/2007 14:42'!
kalseyTabsCss
	"this is from http://kalsey.com/tools/csstabs/ - would also be nice to do http://www.alistapart.com/articles/slidingdoors/"
	^ '
.kalsey .navigation-options {
	border-bottom : 1px solid #ccc;
	margin : 0;
	padding-bottom : 19px;
	padding-left : 10px;
}

.kalsey .navigation-options ul, .kalsey .navigation-options li	{
	display : inline;
	list-style-type : none;
	margin : 0;
	padding : 0;
}


.kalsey .navigation-options a:link, .kalsey .navigation-options a:visited	{
	background : #E8EBF0;
	border : 1px solid #ccc;
	color : #666;
	float : left;
	font-size : small;
	font-weight : normal;
	line-height : 14px;
	margin-right : 8px;
	padding : 2px 10px 2px 10px;
	text-decoration : none;
}

.kalsey .navigation-options a:link.active, .kalsey .navigation-options a:visited.active	{
	background : #fff;
	border-bottom : 1px solid #fff;
	color : #000;
}

.kalsey .navigation-options ul a:hover	{
	color : #f00;
}

.kalsey .navigation-options .option-selected a {
	background : #fff;
	border-bottom : 1px solid #fff;
	color : #000;
}

.kalsey .navigation-content {
	background : #fff;
	border : 1px solid #ccc;
	border-top : none;
	clear : both;
	margin : 0px;
	padding : 15px;
	line-height: 1.1;  /* IE6 CSS workaround - http://www.dracos.co.uk/web/css/ie6floatbug/ */
}
'! !

!WAStandardFiles methodsFor: 'accessing' stamp: 'lr 12/27/2008 16:17'!
selectorsToInclude
	^#(
		windowCss
		kalseyTabsCss
	)! !

!WAStandardFiles methodsFor: 'accessing-styles' stamp: 'lr 12/30/2008 17:08'!
windowCss
	^ '.window {
	margin: 1em;
	border: 1px solid #aaa;
}
.window .window-titlebar {
	color: #444;
	padding: 5px;
	overflow: hidden;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.window .window-titlebar .window-title {
	float: left;
	font-weight: bold;
	padding-left: 20px;
}
.window .window-titlebar .window-close {
	float: right;
}
.window .window-titlebar .window-close a {
	color: #444;
	text-decoration: none;
}
.window .window-titlebar .window-close a:hover {
	color: #111;
}
.window .window-content {
	clear: both;
	padding: 2px;
	background-color: #fff;
}'! !

!WAComponent class methodsFor: '*seaside-environment' stamp: 'lr 12/30/2008 12:48'!
registerAsApplication: aString 
	self
		seasideDeprecatedApi: 'WAComponent class>>#registerAsApplication:'
		details: 'Use WAAdmin class>>#register:asApplicationAt:.'.
	^ WAAdmin register: self asApplicationAt: aString! !

WAResponseFactory subclass: #WAHtmlResponseFactory
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Environment'!

!WAHtmlResponseFactory class methodsFor: 'response-generation' stamp: 'jf 9/14/2008 00:36'!
forbiddenForContext: aRequestContext
	| response content |
	response := WAResponse new.
	response forbidden.
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Forbidden' ];
		render: [ :html |
			html heading level1; with: [
				html text: 'Error: you are forbidden to access "'.
				html text: aRequestContext request url.
				html text: '"' ] ].
	response nextPutAll: content.
	^ response! !

!WAHtmlResponseFactory class methodsFor: 'response-generation' stamp: 'jf 9/14/2008 00:35'!
notFoundForContext: aRequestContext 
	| response content |
	response := WAResponse new.
	response notFound.
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Not Found' ];
		render: [ :html |
			html heading level1; with: [
				html text: 'Error: "'.
				html text: aRequestContext request url.
				html text: '" not found' ] ].
	response nextPutAll: content.
	^ response! !

!WAHtmlResponseFactory class methodsFor: 'response-generation' stamp: 'pmm 9/14/2008 13:56'!
pageExpiredForContext: aRequestContext
	| content |
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Page Expired' ];
		render: [ :html | 
			html heading: 'Page Expired'.
			html paragraph: 'This page has expired. Please use the back-button to navigate to the last valid page.' ].
	^WAResponse new
		nextPutAll: content;
		doNotCache;
		yourself! !

!WAHtmlResponseFactory class methodsFor: 'response-generation' stamp: 'jf 9/14/2008 00:36'!
refreshAfter: aNumber location: aUrlOrString message: aString
	| response document |
	response := WAResponse new.
	response refreshAfter: aNumber location: aUrlOrString.
	
	document := WARenderCanvas builder
		fullDocument: true;
		render: [ :html |
			html heading level1; with: aString.
			html paragraph: [
				html text: 'You are being redirected to '.
				html anchor
					url: aUrlOrString;
					with: aUrlOrString seasideString ] ].
	
	response nextPutAll: document.
		
	^ response! !
WAAdmin initialize!
